==> cdktf_cdktf_provider_azurerm-0.5.16-py3-none-any.whl: package/lib/data-azurerm-netapp-snapshot-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzurermNetappSnapshotPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#account_name DataAzurermNetappSnapshotPolicy#account_name}.
     *
     * @stability stable
     */
    readonly accountName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#name DataAzurermNetappSnapshotPolicy#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#resource_group_name DataAzurermNetappSnapshotPolicy#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#timeouts DataAzurermNetappSnapshotPolicy#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzurermNetappSnapshotPolicyTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicyDailySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hour(): number;
    /**
     * @stability stable
     */
    get minute(): number;
    /**
     * @stability stable
     */
    get snapshotsToKeep(): number;
}
/**
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicyHourlySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get minute(): number;
    /**
     * @stability stable
     */
    get snapshotsToKeep(): number;
}
/**
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicyMonthlySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get daysOfMonth(): number[];
    /**
     * @stability stable
     */
    get hour(): number;
    /**
     * @stability stable
     */
    get minute(): number;
    /**
     * @stability stable
     */
    get snapshotsToKeep(): number;
}
/**
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicyWeeklySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get daysOfWeek(): string[];
    /**
     * @stability stable
     */
    get hour(): number;
    /**
     * @stability stable
     */
    get minute(): number;
    /**
     * @stability stable
     */
    get snapshotsToKeep(): number;
}
/**
 * @stability stable
 */
export interface DataAzurermNetappSnapshotPolicyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#read DataAzurermNetappSnapshotPolicy#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
export declare function dataAzurermNetappSnapshotPolicyTimeoutsToTerraform(struct?: DataAzurermNetappSnapshotPolicyTimeoutsOutputReference | DataAzurermNetappSnapshotPolicyTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataAzurermNetappSnapshotPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataAzurermNetappSnapshotPolicyTimeouts | undefined);
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy azurerm_netapp_snapshot_policy}.
 *
 * @stability stable
 */
export declare class DataAzurermNetappSnapshotPolicy extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy azurerm_netapp_snapshot_policy} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAzurermNetappSnapshotPolicyConfig);
    private _accountName?;
    /**
     * @stability stable
     */
    get accountName(): string;
    /**
     * @stability stable
     */
    set accountName(value: string);
    /**
     * @stability stable
     */
    get accountNameInput(): string | undefined;
    /**
     * @stability stable
     */
    dailySchedule(index: string): DataAzurermNetappSnapshotPolicyDailySchedule;
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    hourlySchedule(index: string): DataAzurermNetappSnapshotPolicyHourlySchedule;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    monthlySchedule(index: string): DataAzurermNetappSnapshotPolicyMonthlySchedule;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    /**
     * @stability stable
     */
    tags(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    weeklySchedule(index: string): DataAzurermNetappSnapshotPolicyWeeklySchedule;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DataAzurermNetappSnapshotPolicyTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DataAzurermNetappSnapshotPolicyTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzurermNetappSnapshotPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.5.60-py3-none-any.whl: package/lib/data-azurerm-netapp-snapshot-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermNetappSnapshotPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#account_name DataAzurermNetappSnapshotPolicy#account_name}
    */
    readonly accountName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#name DataAzurermNetappSnapshotPolicy#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#resource_group_name DataAzurermNetappSnapshotPolicy#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#timeouts DataAzurermNetappSnapshotPolicy#timeouts}
    */
    readonly timeouts?: DataAzurermNetappSnapshotPolicyTimeouts;
}
export declare class DataAzurermNetappSnapshotPolicyDailySchedule extends cdktf.ComplexComputedList {
    get hour(): number;
    get minute(): number;
    get snapshotsToKeep(): number;
}
export declare class DataAzurermNetappSnapshotPolicyHourlySchedule extends cdktf.ComplexComputedList {
    get minute(): number;
    get snapshotsToKeep(): number;
}
export declare class DataAzurermNetappSnapshotPolicyMonthlySchedule extends cdktf.ComplexComputedList {
    get daysOfMonth(): number[];
    get hour(): number;
    get minute(): number;
    get snapshotsToKeep(): number;
}
export declare class DataAzurermNetappSnapshotPolicyWeeklySchedule extends cdktf.ComplexComputedList {
    get daysOfWeek(): string[];
    get hour(): number;
    get minute(): number;
    get snapshotsToKeep(): number;
}
export interface DataAzurermNetappSnapshotPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy#read DataAzurermNetappSnapshotPolicy#read}
    */
    readonly read?: string;
}
export declare function dataAzurermNetappSnapshotPolicyTimeoutsToTerraform(struct?: DataAzurermNetappSnapshotPolicyTimeoutsOutputReference | DataAzurermNetappSnapshotPolicyTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermNetappSnapshotPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermNetappSnapshotPolicyTimeouts | undefined;
    set internalValue(value: DataAzurermNetappSnapshotPolicyTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy azurerm_netapp_snapshot_policy}
*/
export declare class DataAzurermNetappSnapshotPolicy extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/netapp_snapshot_policy azurerm_netapp_snapshot_policy} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermNetappSnapshotPolicyConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermNetappSnapshotPolicyConfig);
    private _accountName?;
    get accountName(): string;
    set accountName(value: string);
    get accountNameInput(): string | undefined;
    dailySchedule(index: string): DataAzurermNetappSnapshotPolicyDailySchedule;
    get enabled(): cdktf.IResolvable;
    hourlySchedule(index: string): DataAzurermNetappSnapshotPolicyHourlySchedule;
    get id(): string;
    get location(): string;
    monthlySchedule(index: string): DataAzurermNetappSnapshotPolicyMonthlySchedule;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    tags(key: string): string | cdktf.IResolvable;
    weeklySchedule(index: string): DataAzurermNetappSnapshotPolicyWeeklySchedule;
    private _timeouts;
    get timeouts(): DataAzurermNetappSnapshotPolicyTimeoutsOutputReference;
    putTimeouts(value: DataAzurermNetappSnapshotPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermNetappSnapshotPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
